%define	name	cdrdao
%define version 1.2.2
%define build_plf 0
%{?_with_plf: %{expand: %%global build_plf 1}}
%define release %mkrel 8
%if %build_plf
%define distsuffix plf
%endif

Summary:	Cdrdao - Write CDs in disk-at-once mode
Name:		%{name}
Version:	%{version}
Release:	%{release}
License:	GPLv2+
Group:		Archiving/Cd burning
URL:		http://cdrdao.sourceforge.net/
Source0:	http://prdownloads.sourceforge.net/cdrdao/%{name}-%{version}.tar.bz2
# Fixes use of old sigc++ API breaking compilation. Fix discovered
# by Pixel - AdamW 2007/09
Patch0:		cdrdao-1.2.2-sigc.patch
Patch1:		mkisofs-changelog.patch 
Patch2:		cdrdao-1.2.2-gcc43.patch
Patch9:		cdrdao-1.1.7-endianness.patch
Patch23:	cdrtools-2.01a27-silly-warnings.patch
Patch30:	cdrtools-2.0-O_EXCL.patch
BuildRequires:	libvorbis-devel
BuildRequires:	libmad-devel
BuildRequires:	libao-devel
BuildRequires:	imagemagick
BuildRequires:	desktop-file-utils
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Writes CDs in disc-at-once (DAO) mode allowing control over pre-gaps
(length down to 0, nonzero audio data) and sub-channel information
like ISRC codes. All data that is written to the disc must be
specified with a text file. Audio data may be in WAVE or raw format.
%if %build_plf

This package is in PLF as it violates some patents for MP3 encoding.
%endif

%package	gcdmaster
Summary:	Graphical front end to cdrdao for creating audio CDs
Group:		Archiving/Cd burning
Obsoletes:	cdrdao-xdao cdrdao-xcdrdao
BuildRequires:	libgnomeuimm2.6-devel
Provides:	cdrdao-xdao cdrdao-xcdrdao

Requires:		%{name} = %{version}
Requires(post):		shared-mime-info
Requires(postun):	shared-mime-info
Requires(post):		desktop-file-utils
Requires(postun):	desktop-file-utils

%description    gcdmaster
gcdmaster allows the creation of toc-files for cdrdao and can control
the recording process. Its main application is the creation of audio
CDs from one or more audio files. It supports PQ-channel editing,
entry of meta data like ISRC codes/CD-TEXT and non-destructive cut of
the audio data.

%if %build_plf
%package	toc2mp3
Summary:	Command line MP3 encoder front end to cdrdao
Group:		Sound
BuildRequires:	liblame-devel
Requires:	%{name} = %{version}

%description	toc2mp3
This is a command line MP3 encoder that converts audio CD disc images
(toc files) to MP3 files. Special care is taken that the MP3 files can
be played in sequence without having unwanted noise at the transition
points. CD-TEXT information (if available) is used to set ID3 (v2)
tags and to construct the name of the MP3 files.

This package is in PLF as it violates some patents for MP3 encoding.
%endif

%prep

%setup -q
%patch0 -p1 -b .sigc
%patch1 -p1 -b .changelog
%patch2 -p1 -b .gcc43
%patch9 -p1 -b .endian
%patch23 -p1 -b .silly
%patch30 -p1 -b .excl

%build
export CXXFLAGS="%optflags -DENABLE_NLS"
%configure2_5x
%make

%install
rm -rf %buildroot
%makeinstall

# Menu
perl -pi -e 's,gcdmaster.png,gcdmaster,g' %{buildroot}%{_datadir}/applications/*
desktop-file-install --vendor="" \
  --remove-category="Application" \
  --remove-category="X-Fedora" \
  --remove-key="Encoding" \
  --add-category="GTK" \
  --add-category="AudioVideo" \
  --add-category="DiscBurning" \
  --dir %{buildroot}%{_datadir}/applications %{buildroot}%{_datadir}/applications/*
  
# icon
mkdir -p %{buildroot}%{_iconsdir}/hicolor/{16x16,32x32,48x48}/apps
convert -scale 16 xdao/gcdmaster.png %{buildroot}%{_iconsdir}/hicolor/16x16/apps/gcdmaster.png
convert -scale 32 xdao/gcdmaster.png %{buildroot}%{_iconsdir}/hicolor/32x32/apps/gcdmaster.png
install -m 644 xdao/gcdmaster.png %{buildroot}%{_iconsdir}/hicolor/48x48/apps/gcdmaster.png
 
%if %mdkversion < 200900
%post gcdmaster
%{update_menus}
%{update_icon_cache hicolor}
%endif

%if %mdkversion < 200900
%postun gcdmaster
%{clean_menus}
%{clean_icon_cache hicolor}
%endif

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc README README.PlexDAE
%doc %{_mandir}/man1/*
%attr(6755,root,cdwriter) %{_bindir}/cdrdao
%{_bindir}/toc2cue
%{_bindir}/toc2cddb
%{_bindir}/cue2toc
%{_datadir}/%{name}

%files	gcdmaster
%defattr(-,root,root)
%{_bindir}/gcdmaster
%{_datadir}/applications/gcdmaster.desktop
%{_datadir}/application-registry/gcdmaster.applications
%{_datadir}/gcdmaster
%{_datadir}/mime-info/gcdmaster.keys
%{_datadir}/mime-info/gcdmaster.mime
%{_datadir}/mime/packages/gcdmaster.xml
%{_datadir}/pixmaps/*
%{_iconsdir}/hicolor/*/apps/*

%if %build_plf
%files toc2mp3
%defattr(-,root,root)
%{_bindir}/toc2mp3
%endif



%changelog
* Wed Aug 06 2008 Thierry Vignaud <tvignaud@mandriva.com> 1.2.2-8mdv2009.0
+ Revision: 264347
- rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Fri May 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.2-7mdv2009.0
+ Revision: 210280
- more gcc43 fixes
- sync with fedora

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 1.2.2-6mdv2008.1
+ Revision: 136290
- restore BuildRoot

  + Thierry Vignaud <tvignaud@mandriva.com>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Sep 12 2007 Götz Waschk <waschk@mandriva.org> 1.2.2-6mdv2008.0
+ Revision: 84783
- fix description

* Tue Sep 11 2007 Adam Williamson <awilliamson@mandriva.com> 1.2.2-5mdv2008.0
+ Revision: 84331
- add patch0 to fix compilation issue caused by use of old sigc++ API
- don't buildrequire cdrecord-devel any more
-rebuild for 2008
- no need to update mime database as the .desktop file contains no mime types
- fix encoding and icon errors in .desktop file
- drop X-Mandriva and X-Fedora menu categories
- fd.o icons
- drop legacy menu and icons
- s/mp3/MP3/
- rewrap descriptions
- Fedora license policy

  + Götz Waschk <waschk@mandriva.org>
    - fix description (bug #32017)


* Wed Oct 18 2006 Götz Waschk <waschk@mandriva.org>
+ 2006-10-17 12:47:21 (65871)
rebuild

* Tue Oct 17 2006 Götz Waschk <waschk@mandriva.org>
+ 2006-10-16 07:25:36 (65483)
rebuild

* Fri Oct 13 2006 Götz Waschk <waschk@mandriva.org>
+ 2006-10-12 07:48:55 (63699)
rebuild

* Fri Oct 13 2006 Götz Waschk <waschk@mandriva.org>
+ 2006-10-12 07:42:18 (63698)
rebuild

* Mon Oct 09 2006 Götz Waschk <waschk@mandriva.org>
+ 2006-10-08 13:30:36 (63025)
Import cdrdao

* Sat Sep 23 2006 Gtz Waschk <waschk@mandriva.org> 1.2.2-1mdv2007.0
- drop patch
- New version 1.2.2

* Thu Aug 24 2006 Gtz Waschk <waschk@mandriva.org> 1.2.1-3mdv2007.0
- rebuild for new cairomm

* Sat Jun 17 2006 Gtz Waschk <waschk@mandriva.org> 1.2.1-2mdv2007.0
- xdg menu
- fix build with gcc 4.1

* Sat Nov 26 2005 Gtz Waschk <waschk@mandriva.org> 1.2.1-1mdk
- drop patches
- New release 1.2.1

* Sun Jul 31 2005 Nicolas Lcureuil <neoclust@mandriva.org> 1.2.0-2mdk
- Patch 1 : Fix Compile with Gcc4

* Sat May 14 2005 Gtz Waschk <waschk@mandriva.org> 1.2.0-1mdk
- update file list
- bump deps
- drop patches 3,4
- mkrel
- new version

* Thu Dec 16 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 1.1.9-7mdk
- fix buildrequires
. fix ambigous operator cast (P4 from fedora)

* Fri Sep 03 2004 Marcel Pol <mpol@mandrake.org> 1.1.9-6mdk
- fix menu section

* Wed Jun 16 2004 Götz Waschk <waschk@linux-mandrake.com> 1.1.9-5mdk
- use official icon
- add missing files
- patch 3 for some gcc 3.4 fixes
- drop merged patches 1,2
- add source URL
- New release 1.1.9

* Fri May 14 2004 Götz Waschk <waschk@linux-mandrake.com> 1.1.8-5mdk
- C++ fixes from Gwenole Beauchesne

* Sun Apr 18 2004 Götz Waschk <waschk@linux-mandrake.com> 1.1.8-4mdk
- fix toc2mp3 package

* Sun Apr 18 2004 Götz Waschk <waschk@linux-mandrake.com> 1.1.8-3mdk
- gcdmaster depends on cdrdao

* Wed Mar 24 2004 Götz Waschk <waschk@linux-mandrake.com> 1.1.8-2mdk
- patch1: don't add kernel includes
- add subpackage for toc2mp3
- real 1.1.8 final

* Fri Mar 12 2004 Warly <warly@mandrakesoft.com> 1.1.8-1mdk
- 1.1.8 final
- add buildrequires cdrecord-devel

* Sun Jan 11 2004 Götz Waschk <waschk@linux-mandrake.com> 1.1.8-0.pre2.0.20040106.1mdk
- set suid bit on the cdrdao executable
- add toc2cddb
- new cvs snapshot

